@@ -320,6 +320,23 @@ extern void glXBindTexImageEXT(Display *dpy, GLXDrawable drawable, int buffer,
                                const int *attrib_list);
 extern void glXReleaseTexImageEXT(Display *dpy, GLXDrawable drawable, int buffer);
 
+/*
+ * SGIX_video_resize
+ */
+extern int glXBindChannelToWindowSGIX(Display *display,
+                                      int screen, int channel, Window window);
+
+extern int glXChannelRectSGIX(Display *display, int screen, int channel,
+                              int x, int y, int w, int h);
+
+extern int glXQueryChannelRectSGIX(Display *display, int screen, int channel,
+                                   int *dx, int *dy, int *dw, int *dh);
+
+extern int glXQueryChannelDeltasSGIX(Display *display, int screen, int channel,
+                                     int *x, int *y, int *w, int *h);
+
+extern int glXChannelRectSyncSGIX(Display *display, int screen, int channel,
+                                  GLenum synctype);
 
 /**********************************************************************/
 
