@@ -483,25 +483,14 @@ int nvidia_open_dev(
 
 failed:
     if (sc->refcnt == 0) {
-        if (sc->timer_sp != NULL) {
+        if (sc->timer_sp != NULL)
             NV_UMA_ZONE_FREE_STACK(sc->timer_sp);
-            sc->timer_sp = NULL;
-        }
-
-        if (sc->isr_sp != NULL) {
+        if (sc->isr_sp != NULL)
             NV_UMA_ZONE_FREE_STACK(sc->isr_sp);
-            sc->isr_sp = NULL;
-        }
-
-        if (sc->pci_cfgchk_sp != NULL) {
+        if (sc->pci_cfgchk_sp != NULL)
             NV_UMA_ZONE_FREE_STACK(sc->pci_cfgchk_sp);
-            sc->pci_cfgchk_sp = NULL;
-        }
-
-        if (sc->api_sp != NULL) {
+        if (sc->api_sp != NULL)
             NV_UMA_ZONE_FREE_STACK(sc->api_sp);
-            sc->api_sp = NULL;
-        }
     }
 
     if (new_filep)
@@ -549,16 +538,9 @@ int nvidia_close_dev(
         }
 
         NV_UMA_ZONE_FREE_STACK(sc->timer_sp);
-        sc->timer_sp = NULL;
-
         NV_UMA_ZONE_FREE_STACK(sc->isr_sp);
-        sc->isr_sp = NULL;
-
         NV_UMA_ZONE_FREE_STACK(sc->pci_cfgchk_sp);
-        sc->pci_cfgchk_sp = NULL;
-
         NV_UMA_ZONE_FREE_STACK(sc->api_sp);
-        sc->api_sp = NULL;
 
         nv->flags &= ~NV_FLAG_OPEN;
     }
